<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xlink="http://www.w3.org/1999/xlink" 
	xmlns:marc="http://www.loc.gov/MARC21/slim" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="marc">
	<xsl:include href="MARC21slimUtils.xsl"/>
	<!--<xsl:include href="MARC21slimUtils.xsl"/>-->
	<xsl:output method="xml" indent="yes" encoding="UTF-8"/>

<!--
Revision 2003/03/25 08:29 jrad

Revision 1.6 various validation fixes 2004/02/20 ntra

Revision 1.5  2003/10/02 16:18:58  ntra
MODS2 to MODS3 updates, language unstacking and 
de-duping, chopPunctuation expanded

Revision 1.3  2003/04/03 00:07:19  ntra
Revision 1.3 Additional Changes not related to MODS Version 2.0 by ntra

Revision 1.2  2003/03/24 19:37:42  ckeith
Added Log Comment

-->
	<xsl:template match="/">
		<xsl:choose>
			<xsl:when test="marc:collection">
				<modsCollection xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
				xsi:schemaLocation="http://www.loc.gov/mods/v3 http://www.loc.gov/standards/mods/v3/mods-3-0.xsd">
				</modsCollection>
			</xsl:when>
			<xsl:otherwise>
				<user_info version="1.0">
					<xsl:for-each select="marc:record">
						<xsl:call-template name="marcRecord"/>
					</xsl:for-each>
				</user_info>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="marcRecord">
		<xsl:variable name="leader" select="marc:leader"/>
		<xsl:variable name="leader6" select="substring($leader,7,1)"/>
		<xsl:variable name="leader7" select="substring($leader,8,1)"/>
		<xsl:variable name="controlField008" select="marc:controlfield[@tag=008]"/>
		<xsl:variable name="typeOf008">
			<xsl:choose>
				<xsl:when test="$leader6='a'">
					<xsl:choose>
						<xsl:when test="$leader7='a' or $leader7='c' or $leader7='d' or $leader7='m'">BK</xsl:when>
						<xsl:when test="$leader7='b' or $leader7='i' or $leader7='s'">SE</xsl:when>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="$leader6='t'">BK</xsl:when>
				<xsl:when test="$leader6='p'">MM</xsl:when>
				<xsl:when test="$leader6='m'">CF</xsl:when>
				<xsl:when test="$leader6='e' or $leader6='f'">MP</xsl:when>
				<xsl:when test="$leader6='g' or $leader6='k' or $leader6='o' or $leader6='r'">VM</xsl:when>
				<xsl:when test="$leader6='c' or $leader6='d' or $leader6='i' or $leader6='j'">MU</xsl:when>
			</xsl:choose>
		</xsl:variable>

		<xsl:for-each select="marc:datafield[@tag=010]">
			<identifier>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</identifier>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=110]">
			<fn>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</fn>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=010]">
			<family>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</family>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=011]">
			<name>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</name>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=012]">
			<name1>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</name1>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=050]">
			<category>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</category>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=032]">
			<email>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</email>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=030]">
			<reader_id>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</reader_id>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=021]">
			<year>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</year>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=015]">
			<organization>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</organization>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=016]">
			<position>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</position>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=020]">
			<education>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</education>
		</xsl:for-each>
		<xsl:for-each select="marc:datafield[@tag=040]">
			<books_hystory>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</books_hystory>
		</xsl:for-each>

		<xsl:for-each select="marc:datafield[@tag=150]">
			<e_books_hystory>
				<xsl:value-of select="normalize-space(marc:subfield[@code='a'])"/>
			</e_books_hystory>
		</xsl:for-each>

	</xsl:template>
</xsl:stylesheet>
